""" Cisco_IOS_XR_ip_static_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-static package configuration.

This module contains definitions
for the following management objects\:
  router\-static\: This class represents router static
    configuration

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error




class RouterStatic(Entity):
    """
    This class represents router static configuration
    
    .. attribute:: vrfs
    
    	VRF static configuration container
    	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs>`
    
    .. attribute:: default_vrf
    
    	Default VRF configuration
    	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf>`
    
    .. attribute:: maximum_routes
    
    	The maximum number of static routes that can be configured
    	**type**\:  :py:class:`MaximumRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.MaximumRoutes>`
    
    

    """

    _prefix = 'ip-static-cfg'
    _revision = '2017-05-01'

    def __init__(self):
        super(RouterStatic, self).__init__()
        self._top_entity = None

        self.yang_name = "router-static"
        self.yang_parent_name = "Cisco-IOS-XR-ip-static-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("vrfs", ("vrfs", RouterStatic.Vrfs)), ("default-vrf", ("default_vrf", RouterStatic.DefaultVrf)), ("maximum-routes", ("maximum_routes", RouterStatic.MaximumRoutes))])
        self._leafs = OrderedDict()

        self.vrfs = RouterStatic.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"

        self.default_vrf = RouterStatic.DefaultVrf()
        self.default_vrf.parent = self
        self._children_name_map["default_vrf"] = "default-vrf"

        self.maximum_routes = RouterStatic.MaximumRoutes()
        self.maximum_routes.parent = self
        self._children_name_map["maximum_routes"] = "maximum-routes"
        self._segment_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(RouterStatic, [], name, value)


    class Vrfs(Entity):
        """
        VRF static configuration container
        
        .. attribute:: vrf
        
        	VRF static configuration
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2017-05-01'

        def __init__(self):
            super(RouterStatic.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "router-static"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("vrf", ("vrf", RouterStatic.Vrfs.Vrf))])
            self._leafs = OrderedDict()

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(RouterStatic.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            VRF static configuration
            
            .. attribute:: vrf_name  (key)
            
            	VRF name
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: address_family
            
            	Address family configuration
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily>`
            
            

            """

            _prefix = 'ip-static-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(RouterStatic.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['vrf_name']
                self._child_classes = OrderedDict([("address-family", ("address_family", RouterStatic.Vrfs.Vrf.AddressFamily))])
                self._leafs = OrderedDict([
                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                ])
                self.vrf_name = None

                self.address_family = RouterStatic.Vrfs.Vrf.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"
                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/vrfs/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(RouterStatic.Vrfs.Vrf, ['vrf_name'], name, value)


            class AddressFamily(Entity):
                """
                Address family configuration
                
                .. attribute:: vrfipv4
                
                	IPv4 static configuration
                	**type**\:  :py:class:`Vrfipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4>`
                
                .. attribute:: vrfipv6
                
                	IPv6 static configuration
                	**type**\:  :py:class:`Vrfipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(RouterStatic.Vrfs.Vrf.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrfipv4", ("vrfipv4", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4)), ("vrfipv6", ("vrfipv6", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6))])
                    self._leafs = OrderedDict()

                    self.vrfipv4 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4()
                    self.vrfipv4.parent = self
                    self._children_name_map["vrfipv4"] = "vrfipv4"

                    self.vrfipv6 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6()
                    self.vrfipv6.parent = self
                    self._children_name_map["vrfipv6"] = "vrfipv6"
                    self._segment_path = lambda: "address-family"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily, [], name, value)


                class Vrfipv4(Entity):
                    """
                    IPv4 static configuration
                    
                    .. attribute:: vrf_unicast
                    
                    	Unicast static configuration
                    	**type**\:  :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast>`
                    
                    .. attribute:: vrf_multicast
                    
                    	Multicast static configuration
                    	**type**\:  :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4, self).__init__()

                        self.yang_name = "vrfipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf-unicast", ("vrf_unicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast)), ("vrf-multicast", ("vrf_multicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast))])
                        self._leafs = OrderedDict()

                        self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast()
                        self.vrf_unicast.parent = self
                        self._children_name_map["vrf_unicast"] = "vrf-unicast"

                        self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast()
                        self.vrf_multicast.parent = self
                        self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        self._segment_path = lambda: "vrfipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4, [], name, value)


                    class VrfUnicast(Entity):
                        """
                        Unicast static configuration
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes>`
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast, self).__init__()

                            self.yang_name = "vrf-unicast"
                            self.yang_parent_name = "vrfipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology))])
                            self._leafs = OrderedDict()

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._segment_path = lambda: "vrf-unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast, [], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology))])
                                self._leafs = OrderedDict()

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  (key)
                                
                                	Topology name
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['topology_name']
                                    self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies))])
                                    self._leafs = OrderedDict([
                                        ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                    ])
                                    self.topology_name = None

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                        self._leafs = OrderedDict()

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  (key)
                                        
                                        	Destination prefix
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length  (key)
                                        
                                        	Destination prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix','prefix_length']
                                            self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._segment_path = lambda: "vrf-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                                self._leafs = OrderedDict()

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  (key)
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['vrf_name']
                                                    self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                    self._leafs = OrderedDict([
                                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ])
                                                    self.vrf_name = None

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                        self._leafs = OrderedDict()

                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._segment_path = lambda: "vrf-seg-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "default-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, [], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class VrfMulticast(Entity):
                        """
                        Multicast static configuration
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes>`
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast, self).__init__()

                            self.yang_name = "vrf-multicast"
                            self.yang_parent_name = "vrfipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology))])
                            self._leafs = OrderedDict()

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._segment_path = lambda: "vrf-multicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast, [], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology))])
                                self._leafs = OrderedDict()

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  (key)
                                
                                	Topology name
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['topology_name']
                                    self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies))])
                                    self._leafs = OrderedDict([
                                        ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                    ])
                                    self.topology_name = None

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                        self._leafs = OrderedDict()

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  (key)
                                        
                                        	Destination prefix
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length  (key)
                                        
                                        	Destination prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix','prefix_length']
                                            self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._segment_path = lambda: "vrf-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                                self._leafs = OrderedDict()

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  (key)
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['vrf_name']
                                                    self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                    self._leafs = OrderedDict([
                                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ])
                                                    self.vrf_name = None

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                        self._leafs = OrderedDict()

                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._segment_path = lambda: "vrf-seg-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "default-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, [], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                class Vrfipv6(Entity):
                    """
                    IPv6 static configuration
                    
                    .. attribute:: vrf_unicast
                    
                    	Unicast static configuration
                    	**type**\:  :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast>`
                    
                    .. attribute:: vrf_multicast
                    
                    	Multicast static configuration
                    	**type**\:  :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6, self).__init__()

                        self.yang_name = "vrfipv6"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf-unicast", ("vrf_unicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast)), ("vrf-multicast", ("vrf_multicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast))])
                        self._leafs = OrderedDict()

                        self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast()
                        self.vrf_unicast.parent = self
                        self._children_name_map["vrf_unicast"] = "vrf-unicast"

                        self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast()
                        self.vrf_multicast.parent = self
                        self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        self._segment_path = lambda: "vrfipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6, [], name, value)


                    class VrfUnicast(Entity):
                        """
                        Unicast static configuration
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes>`
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast, self).__init__()

                            self.yang_name = "vrf-unicast"
                            self.yang_parent_name = "vrfipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology))])
                            self._leafs = OrderedDict()

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._segment_path = lambda: "vrf-unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast, [], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology))])
                                self._leafs = OrderedDict()

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  (key)
                                
                                	Topology name
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['topology_name']
                                    self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies))])
                                    self._leafs = OrderedDict([
                                        ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                    ])
                                    self.topology_name = None

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                        self._leafs = OrderedDict()

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  (key)
                                        
                                        	Destination prefix
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length  (key)
                                        
                                        	Destination prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix','prefix_length']
                                            self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._segment_path = lambda: "vrf-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                                self._leafs = OrderedDict()

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  (key)
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['vrf_name']
                                                    self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                    self._leafs = OrderedDict([
                                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ])
                                                    self.vrf_name = None

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                        self._leafs = OrderedDict()

                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._segment_path = lambda: "vrf-seg-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "default-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, [], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class VrfMulticast(Entity):
                        """
                        Multicast static configuration
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes>`
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast, self).__init__()

                            self.yang_name = "vrf-multicast"
                            self.yang_parent_name = "vrfipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology))])
                            self._leafs = OrderedDict()

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._segment_path = lambda: "vrf-multicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast, [], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology))])
                                self._leafs = OrderedDict()

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  (key)
                                
                                	Topology name
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['topology_name']
                                    self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies))])
                                    self._leafs = OrderedDict([
                                        ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                    ])
                                    self.topology_name = None

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                        self._leafs = OrderedDict()

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  (key)
                                        
                                        	Destination prefix
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length  (key)
                                        
                                        	Destination prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix','prefix_length']
                                            self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._segment_path = lambda: "vrf-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                                self._leafs = OrderedDict()

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  (key)
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['vrf_name']
                                                    self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                    self._leafs = OrderedDict([
                                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ])
                                                    self.vrf_name = None

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                        self._leafs = OrderedDict()

                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  (key)
                                                        
                                                        	Forwarding interface
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.interface_name = None
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  (key)
                                                        
                                                        	Next hop address
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.next_hop_address = None
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  (key)
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\: int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\: bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\: str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['explicit_path_name']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                            ])
                                                            self.explicit_path_name = None
                                                            self.bfd_fast_detect = None
                                                            self.minimum_interval = None
                                                            self.detect_multiplier = None
                                                            self.metric = None
                                                            self.tag = None
                                                            self.permanent = None
                                                            self.vrf_lable = None
                                                            self.tunnel_id = None
                                                            self.object_name = None
                                                            self.description = None
                                                            self.load_metric = None
                                                            self.index = None
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                                self._leafs = OrderedDict()

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._segment_path = lambda: "vrf-seg-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "default-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, [], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


    class DefaultVrf(Entity):
        """
        Default VRF configuration
        
        .. attribute:: address_family
        
        	Address family configuration
        	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily>`
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2017-05-01'

        def __init__(self):
            super(RouterStatic.DefaultVrf, self).__init__()

            self.yang_name = "default-vrf"
            self.yang_parent_name = "router-static"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("address-family", ("address_family", RouterStatic.DefaultVrf.AddressFamily))])
            self._leafs = OrderedDict()

            self.address_family = RouterStatic.DefaultVrf.AddressFamily()
            self.address_family.parent = self
            self._children_name_map["address_family"] = "address-family"
            self._segment_path = lambda: "default-vrf"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(RouterStatic.DefaultVrf, [], name, value)


        class AddressFamily(Entity):
            """
            Address family configuration
            
            .. attribute:: vrfipv4
            
            	IPv4 static configuration
            	**type**\:  :py:class:`Vrfipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4>`
            
            .. attribute:: vrfipv6
            
            	IPv6 static configuration
            	**type**\:  :py:class:`Vrfipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6>`
            
            

            """

            _prefix = 'ip-static-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(RouterStatic.DefaultVrf.AddressFamily, self).__init__()

                self.yang_name = "address-family"
                self.yang_parent_name = "default-vrf"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrfipv4", ("vrfipv4", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4)), ("vrfipv6", ("vrfipv6", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6))])
                self._leafs = OrderedDict()

                self.vrfipv4 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4()
                self.vrfipv4.parent = self
                self._children_name_map["vrfipv4"] = "vrfipv4"

                self.vrfipv6 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6()
                self.vrfipv6.parent = self
                self._children_name_map["vrfipv6"] = "vrfipv6"
                self._segment_path = lambda: "address-family"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily, [], name, value)


            class Vrfipv4(Entity):
                """
                IPv4 static configuration
                
                .. attribute:: vrf_unicast
                
                	Unicast static configuration
                	**type**\:  :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast>`
                
                .. attribute:: vrf_multicast
                
                	Multicast static configuration
                	**type**\:  :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4, self).__init__()

                    self.yang_name = "vrfipv4"
                    self.yang_parent_name = "address-family"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf-unicast", ("vrf_unicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast)), ("vrf-multicast", ("vrf_multicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast))])
                    self._leafs = OrderedDict()

                    self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast()
                    self.vrf_unicast.parent = self
                    self._children_name_map["vrf_unicast"] = "vrf-unicast"

                    self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast()
                    self.vrf_multicast.parent = self
                    self._children_name_map["vrf_multicast"] = "vrf-multicast"
                    self._segment_path = lambda: "vrfipv4"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4, [], name, value)


                class VrfUnicast(Entity):
                    """
                    Unicast static configuration
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes>`
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast, self).__init__()

                        self.yang_name = "vrf-unicast"
                        self.yang_parent_name = "vrfipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology))])
                        self._leafs = OrderedDict()

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._segment_path = lambda: "vrf-unicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast, [], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology))])
                            self._leafs = OrderedDict()

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  (key)
                            
                            	Topology name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['topology_name']
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict([
                                    ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ])
                                self.topology_name = None

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/topologies/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  (key)
                            
                            	Destination prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length  (key)
                            
                            	Destination prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['prefix','prefix_length']
                                self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/vrf-prefixes/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._segment_path = lambda: "vrf-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                    self._leafs = OrderedDict()

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  (key)
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf_name']
                                        self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.vrf_name = None

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._segment_path = lambda: "vrf-seg-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, [], name, value)


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/default-topology/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                class VrfMulticast(Entity):
                    """
                    Multicast static configuration
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes>`
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast, self).__init__()

                        self.yang_name = "vrf-multicast"
                        self.yang_parent_name = "vrfipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology))])
                        self._leafs = OrderedDict()

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._segment_path = lambda: "vrf-multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast, [], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology))])
                            self._leafs = OrderedDict()

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  (key)
                            
                            	Topology name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['topology_name']
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict([
                                    ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ])
                                self.topology_name = None

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/topologies/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  (key)
                            
                            	Destination prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length  (key)
                            
                            	Destination prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['prefix','prefix_length']
                                self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/vrf-prefixes/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._segment_path = lambda: "vrf-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                    self._leafs = OrderedDict()

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  (key)
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf_name']
                                        self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.vrf_name = None

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._segment_path = lambda: "vrf-seg-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, [], name, value)


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/default-topology/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


            class Vrfipv6(Entity):
                """
                IPv6 static configuration
                
                .. attribute:: vrf_unicast
                
                	Unicast static configuration
                	**type**\:  :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast>`
                
                .. attribute:: vrf_multicast
                
                	Multicast static configuration
                	**type**\:  :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6, self).__init__()

                    self.yang_name = "vrfipv6"
                    self.yang_parent_name = "address-family"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf-unicast", ("vrf_unicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast)), ("vrf-multicast", ("vrf_multicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast))])
                    self._leafs = OrderedDict()

                    self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast()
                    self.vrf_unicast.parent = self
                    self._children_name_map["vrf_unicast"] = "vrf-unicast"

                    self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast()
                    self.vrf_multicast.parent = self
                    self._children_name_map["vrf_multicast"] = "vrf-multicast"
                    self._segment_path = lambda: "vrfipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6, [], name, value)


                class VrfUnicast(Entity):
                    """
                    Unicast static configuration
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes>`
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast, self).__init__()

                        self.yang_name = "vrf-unicast"
                        self.yang_parent_name = "vrfipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology))])
                        self._leafs = OrderedDict()

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._segment_path = lambda: "vrf-unicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast, [], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology))])
                            self._leafs = OrderedDict()

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  (key)
                            
                            	Topology name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['topology_name']
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict([
                                    ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ])
                                self.topology_name = None

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/topologies/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  (key)
                            
                            	Destination prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length  (key)
                            
                            	Destination prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['prefix','prefix_length']
                                self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/vrf-prefixes/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._segment_path = lambda: "vrf-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                    self._leafs = OrderedDict()

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  (key)
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf_name']
                                        self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.vrf_name = None

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._segment_path = lambda: "vrf-seg-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, [], name, value)


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/default-topology/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                class VrfMulticast(Entity):
                    """
                    Multicast static configuration
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:  :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes>`
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:  :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast, self).__init__()

                        self.yang_name = "vrf-multicast"
                        self.yang_parent_name = "vrfipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topologies", ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies)), ("vrf-prefixes", ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes)), ("default-topology", ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology))])
                        self._leafs = OrderedDict()

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._segment_path = lambda: "vrf-multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast, [], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topology", ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology))])
                            self._leafs = OrderedDict()

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  (key)
                            
                            	Topology name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['topology_name']
                                self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies))])
                                self._leafs = OrderedDict([
                                    ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ])
                                self.topology_name = None

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._segment_path = lambda: "topology" + "[topology-name='" + str(self.topology_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/topologies/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology))])
                                    self._leafs = OrderedDict()

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	Destination prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  (key)
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix','prefix_length']
                                        self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._segment_path = lambda: "vrf-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                            self._leafs = OrderedDict()

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  (key)
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['vrf_name']
                                                self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.vrf_name = None

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                    self._leafs = OrderedDict()

                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  (key)
                                                    
                                                    	Forwarding interface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['interface_name','next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.interface_name = None
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  (key)
                                                    
                                                    	Next hop address
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.next_hop_address = None
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  (key)
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\: bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\: str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['explicit_path_name']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                            ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                            ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                            ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                            ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                            ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                        ])
                                                        self.explicit_path_name = None
                                                        self.bfd_fast_detect = None
                                                        self.minimum_interval = None
                                                        self.detect_multiplier = None
                                                        self.metric = None
                                                        self.tag = None
                                                        self.permanent = None
                                                        self.vrf_lable = None
                                                        self.tunnel_id = None
                                                        self.object_name = None
                                                        self.description = None
                                                        self.load_metric = None
                                                        self.index = None
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                            self._leafs = OrderedDict()

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._segment_path = lambda: "vrf-seg-route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of  		 :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix", ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  (key)
                            
                            	Destination prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length  (key)
                            
                            	Destination prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['prefix','prefix_length']
                                self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/vrf-prefixes/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._segment_path = lambda: "vrf-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, [], name, value)


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute))])
                                    self._leafs = OrderedDict()

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  (key)
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf_name']
                                        self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.vrf_name = None

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable))])
                                    self._leafs = OrderedDict()

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._segment_path = lambda: "vrf-seg-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, [], name, value)


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	Forwarding interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name','next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  (key)
                                        
                                        	Next hop address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.next_hop_address = None
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  (key)
                                        
                                        	Segment Routing mpls path name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\: str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\: str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\: int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['explicit_path_name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ])
                                            self.explicit_path_name = None
                                            self.bfd_fast_detect = None
                                            self.minimum_interval = None
                                            self.detect_multiplier = None
                                            self.metric = None
                                            self.tag = None
                                            self.permanent = None
                                            self.vrf_lable = None
                                            self.tunnel_id = None
                                            self.object_name = None
                                            self.description = None
                                            self.load_metric = None
                                            self.index = None
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:  :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-prefix-topologies", ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies))])
                            self._leafs = OrderedDict()

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, [], name, value)


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of  		 :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf-prefix-topology", ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology))])
                                self._leafs = OrderedDict()

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/default-topology/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  (key)
                                
                                	Destination prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  (key)
                                
                                	Destination prefix length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:  :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:  :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:  :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['prefix','prefix_length']
                                    self._child_classes = OrderedDict([("vrf-route", ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute)), ("vrf-recurse-routes", ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes)), ("vrf-seg-route", ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + str(self.prefix) + "']" + "[prefix-length='" + str(self.prefix_length) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-next-hop-table", ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._segment_path = lambda: "vrf-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, [], name, value)


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of  		 :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-recurse-route", ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute))])
                                        self._leafs = OrderedDict()

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  (key)
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:  :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_name']
                                            self._child_classes = OrderedDict([("vrf-recursive-next-hop-table", ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable))])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.vrf_name = None

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + str(self.vrf_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName))])
                                                self._leafs = OrderedDict()

                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  (key)
                                                
                                                	Forwarding interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['interface_name','next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  (key)
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  (key)
                                                
                                                	Segment Routing mpls path name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\: int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\: str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\: str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\: int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['explicit_path_name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                        ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                        ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                        ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                        ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                        ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                    ])
                                                    self.explicit_path_name = None
                                                    self.bfd_fast_detect = None
                                                    self.minimum_interval = None
                                                    self.detect_multiplier = None
                                                    self.metric = None
                                                    self.tag = None
                                                    self.permanent = None
                                                    self.vrf_lable = None
                                                    self.tunnel_id = None
                                                    self.object_name = None
                                                    self.description = None
                                                    self.load_metric = None
                                                    self.index = None
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:  :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-route-next-hop-table", ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable))])
                                        self._leafs = OrderedDict()

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._segment_path = lambda: "vrf-seg-route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, [], name, value)


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of  		 :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf-next-hop-interface-name", ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName)), ("vrf-next-hop-interface-name-next-hop-address", ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress)), ("vrf-next-hop-next-hop-address", ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress)), ("vrf-next-hop-next-hop-address-explicit-path-name", ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)), ("vrf-next-hop-explicit-path-name", ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName))])
                                            self._leafs = OrderedDict()

                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Forwarding interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name','next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + str(self.interface_name) + "']" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + str(self.next_hop_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  (key)
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['next_hop_address','explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.next_hop_address = None
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + str(self.next_hop_address) + "']" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  (key)
                                            
                                            	Segment Routing mpls path name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\: str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\: str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\: int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['explicit_path_name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('bfd_fast_detect', (YLeaf(YType.boolean, 'bfd-fast-detect'), ['bool'])),
                                                    ('minimum_interval', (YLeaf(YType.uint32, 'minimum-interval'), ['int'])),
                                                    ('detect_multiplier', (YLeaf(YType.uint32, 'detect-multiplier'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('permanent', (YLeaf(YType.boolean, 'permanent'), ['bool'])),
                                                    ('vrf_lable', (YLeaf(YType.uint32, 'vrf-lable'), ['int'])),
                                                    ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                    ('object_name', (YLeaf(YType.str, 'object-name'), ['str'])),
                                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                                ])
                                                self.explicit_path_name = None
                                                self.bfd_fast_detect = None
                                                self.minimum_interval = None
                                                self.detect_multiplier = None
                                                self.metric = None
                                                self.tag = None
                                                self.permanent = None
                                                self.vrf_lable = None
                                                self.tunnel_id = None
                                                self.object_name = None
                                                self.description = None
                                                self.load_metric = None
                                                self.index = None
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + str(self.explicit_path_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'minimum_interval', 'detect_multiplier', 'metric', 'tag', 'permanent', 'vrf_lable', 'tunnel_id', 'object_name', 'description', 'load_metric', 'index'], name, value)


    class MaximumRoutes(Entity):
        """
        The maximum number of static routes that can be
        configured.
        
        .. attribute:: ipv6_routes
        
        	The maximum number of static routes that can be configured for IPv6 AFI
        	**type**\: int
        
        	**range:** 1..140000
        
        	**default value**\: 4000
        
        .. attribute:: ipv4_routes
        
        	The maximum number of static routes that can be configured for IPv4 AFI
        	**type**\: int
        
        	**range:** 1..140000
        
        	**default value**\: 4000
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2017-05-01'

        def __init__(self):
            super(RouterStatic.MaximumRoutes, self).__init__()

            self.yang_name = "maximum-routes"
            self.yang_parent_name = "router-static"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('ipv6_routes', (YLeaf(YType.uint32, 'ipv6-routes'), ['int'])),
                ('ipv4_routes', (YLeaf(YType.uint32, 'ipv4-routes'), ['int'])),
            ])
            self.ipv6_routes = None
            self.ipv4_routes = None
            self._segment_path = lambda: "maximum-routes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(RouterStatic.MaximumRoutes, ['ipv6_routes', 'ipv4_routes'], name, value)

    def clone_ptr(self):
        self._top_entity = RouterStatic()
        return self._top_entity

